# Graph API Client
JS Library created to simplify using of GraphQL by using a defined structure for queries and mutations, instead of passing raw strings to the API handler

Just create an instance of the `GraphAPIClient` object and it will take care of the rest

```typescript
class GraphAPIClient {
    constructor(
        axiosRequestConfig: AxiosRequestConfig = {}, 
        clientConfig: IGraphClientConfig = defaultClientConfig
    ) {
        this.axios = axios.create(axiosRequestConfig);
        this.config = Object.assign({}, defaultClientConfig, clientConfig);
    }
}
```

the `axiosRequestConfig` parameter sets default parameters for the internal axios instance, while `clientConfig` sets the default API request payload keys, by default `{query, variables}`

### Requests sending

Just call `client.query` or `client.mutation` to enjoy the magic

##### Query method

```typescript
public query<T>(path: string = '/graphql', requests: GraphQLRequest[], config: AxiosRequestConfig = {}): Promise<T> {
    const body = this.collectRequestBody('query', requests);
    return this.post<T>(path, body, config);
}
```

##### Mutate method

```typescript
public mutate<T>(path: string = '/graphql', requests: GraphQLRequest[], config: AxiosRequestConfig = {}): Promise<T> {
    const body = this.collectRequestBody('mutation', requests);
    return this.post<T>(path, body, config);
}
```

### Requests Generation

Both GraphQL queries and mutations are being generated by the [*graphql-request-generator*](https://github.com/CapitanFindusFI/graphql-request-generator)
library, which I made.  
To read about request generation check the repo's README
