"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = require("axios");
var GeneratorFactory_1 = require("./GeneratorFactory");
var defaultClientConfig = {
    queryPayloadName: 'query',
    variablesPayloadName: 'variables',
};
var GraphAPIClient = /** @class */ (function () {
    function GraphAPIClient(axiosRequestConfig, clientConfig) {
        if (axiosRequestConfig === void 0) { axiosRequestConfig = {}; }
        if (clientConfig === void 0) { clientConfig = defaultClientConfig; }
        this.axios = axios_1.default.create(axiosRequestConfig);
        this.config = Object.assign({}, defaultClientConfig, clientConfig);
    }
    GraphAPIClient.collectRequestValues = function (requests) {
        var requestValues = Object.create({});
        requests.forEach(function (request) {
            var fragmentValues = request.fragmentValues;
            if (fragmentValues) {
                var valueKeys = Object.keys(fragmentValues);
                if (valueKeys.length) {
                    valueKeys.forEach(function (key) {
                        var _a;
                        Object.assign(requestValues, (_a = {},
                            _a[key] = fragmentValues[key],
                            _a));
                    });
                }
            }
        });
        return requestValues;
    };
    GraphAPIClient.prototype.post = function (path, body, config) {
        if (config === void 0) { config = {}; }
        return this.axios.post(path, body, __assign({}, config));
    };
    GraphAPIClient.prototype.collectRequestBody = function (operationType, requests) {
        var _a;
        var generator = GeneratorFactory_1.default.getGenerator(operationType);
        var queryKeyName = this.config.queryPayloadName;
        var variablesKeyName = this.config.variablesPayloadName;
        var queryString = generator.generateRequestString(requests);
        var queryValues = GraphAPIClient.collectRequestValues(requests);
        return _a = {},
            _a[queryKeyName] = queryString,
            _a[variablesKeyName] = queryValues,
            _a;
    };
    GraphAPIClient.prototype.query = function (path, requests, config) {
        if (path === void 0) { path = '/graphql'; }
        if (config === void 0) { config = {}; }
        var body = this.collectRequestBody('query', requests);
        return this.post(path, body, config);
    };
    GraphAPIClient.prototype.mutate = function (path, requests, config) {
        if (path === void 0) { path = '/graphql'; }
        if (config === void 0) { config = {}; }
        var body = this.collectRequestBody('mutation', requests);
        return this.post(path, body, config);
    };
    return GraphAPIClient;
}());
exports.default = GraphAPIClient;
